User

Struct User 

pub struct User {
Show 31 fields pub id: Id, pub created: u128, pub username: String, pub password: String, pub salt: String, pub settings: UserSettings, pub tokens: Vec<Token>, pub legacy_permissions: i32, pub is_verified: bool, pub notification_count: usize, pub follower_count: usize, pub following_count: usize, pub last_seen: u128, pub totp: String, pub recovery_codes: Vec<String>, pub post_count: usize, pub request_count: usize, pub connections: UserConnections, pub stripe_id: String, pub grants: Vec<AuthGrant>, pub associated: Vec<Id>, pub achievements: Vec<Achievement>, pub ban_reason: String, pub is_deactivated: bool, pub ban_expire: u128, pub checkouts: Vec<String>, pub last_policy_consent: u128, pub missed_messages_count: usize, pub views: usize, pub shrimpcamp_link: usize, pub permissions: PermissionsContainer,
}

Fields

id: Idcreated: u128username: Stringpassword: Stringsalt: Stringsettings: UserSettingstokens: Vec<Token>legacy_permissions: i32is_verified: boolnotification_count: usizefollower_count: usizefollowing_count: usizelast_seen: u128totp: String

The TOTP secret for this profile. An empty value means the user has TOTP disabled.

recovery_codes: Vec<String>

The TOTP recovery codes for this profile.

post_count: usizerequest_count: usizeconnections: UserConnections

External service connection details.

stripe_id: String

The user’s Stripe customer ID.

grants: Vec<AuthGrant>

The grants associated with the user’s account.

associated: Vec<Id>

A list of the IDs of all accounts the user has signed into through the UI.

achievements: Vec<Achievement>

Users collect achievements through little actions across the site.

ban_reason: String

The reason the user was banned.

is_deactivated: bool

If the user is deactivated. Deactivated users act almost like deleted users, but their data is not wiped.

ban_expire: u128

The time at which the user’s ban will automatically expire.

checkouts: Vec<String>

The IDs of Stripe checkout sessions that this user has successfully completed.

This should be checked BEFORE applying purchases to ensure that the user hasn’t already applied this purchase.

last_policy_consent: u128

The time in which the user last consented to the site’s policies.

missed_messages_count: usize

The number of messages this user has missed.

views: usize

The number of unique authenticated users who have viewed this user’s profile.

shrimpcamp_link: usize

The ID of the Shrimpcamp account the user is linked to.

permissions: PermissionsContainer

Implementations

Source

impl User

pub fn new(username: String, password: String) -> Self

Create a new User.

pub fn deleted() -> Self

Deleted user profile.

pub fn banned() -> Self

Banned user profile.

pub fn anonymous() -> Self

Anonymous user profile.

pub fn create_token(ip: &str) -> (String, Token)

Create a new token

Returns

(unhashed id, token)

pub fn check_password(&self, against: String) -> bool

Check if the given password is correct for the user.

pub fn parse_mentions(input: &str) -> Vec<String>

Parse user mentions in a given input.

pub fn totp(&self, issuer: Option<String>) -> Option<TOTP>

Get a TOTP from the profile’s totp secret value.

pub fn clean(&mut self)

Clean the struct for public viewing.

pub fn get_grant_by_app_id(&self, id: &Id) -> Option<&AuthGrant>

Get a grant from the user given the grant’s app ID.

Should be used before adding another grant (to ensure the app doesn’t already have a grant for this user).