UserSettings

Struct UserSettings 

pub struct UserSettings {
Show 49 fields pub display_name: String, pub biography: String, pub warning: String, pub private_profile: bool, pub theme_preference: ThemePreference, pub profile_theme: ThemePreference, pub private_last_seen: bool, pub theme_color_surface: String, pub theme_color_text: String, pub theme_color_text_link: String, pub theme_color_shadow: String, pub theme_color_lowered: String, pub theme_color_text_lowered: String, pub theme_color_super_lowered: String, pub theme_color_raised: String, pub theme_color_text_raised: String, pub theme_color_super_raised: String, pub theme_color_primary: String, pub theme_color_text_primary: String, pub theme_color_primary_lowered: String, pub theme_color_secondary: String, pub theme_color_text_secondary: String, pub theme_color_secondary_lowered: String, pub theme_custom_css: String, pub theme_color_online: String, pub theme_color_idle: String, pub theme_color_offline: String, pub disable_other_themes: bool, pub enable_questions: bool, pub motivational_header: String, pub allow_anonymous_questions: bool, pub anonymous_username: String, pub anonymous_avatar_url: String, pub hide_dislikes: bool, pub require_account: bool, pub show_nsfw: bool, pub inbox_homepage: bool, pub muted: Vec<String>, pub enable_drawings: bool, pub all_timeline_hide_answers: bool, pub large_text: bool, pub disable_achievements: bool, pub hide_from_social_lists: bool, pub private_biography: String, pub hide_social_follows: bool, pub location: String, pub links: Vec<(String, String)>, pub auto_nsfw: bool, pub auto_limit_posts: bool,
}

Fields

display_name: Stringbiography: Stringwarning: Stringprivate_profile: booltheme_preference: ThemePreference

The theme shown to the user.

profile_theme: ThemePreference

The theme used on the user’s profile. Setting this to Auto will use the viewing user’s theme_preference setting.

private_last_seen: booltheme_color_surface: String

Page background.

theme_color_text: String

Text on elements with the surface backgrounds.

theme_color_text_link: String

Links on all elements.

theme_color_shadow: String

Box shadow color.

theme_color_lowered: String

Some cards, buttons, or anything else with a darker background color than the surface.

theme_color_text_lowered: String

Text on elements with the lowered backgrounds.

theme_color_super_lowered: String

Borders.

theme_color_raised: String

Some cards, buttons, or anything else with a lighter background color than the surface.

theme_color_text_raised: String

Text on elements with the raised backgrounds.

theme_color_super_raised: String

Some borders.

theme_color_primary: String

Primary color; navigation bar, some buttons, etc.

theme_color_text_primary: String

Text on elements with the primary backgrounds.

theme_color_primary_lowered: String

Hover state for primary buttons.

theme_color_secondary: String

Secondary color.

theme_color_text_secondary: String

Text on elements with the secondary backgrounds.

theme_color_secondary_lowered: String

Hover state for secondary buttons.

theme_custom_css: String

Custom CSS input.

theme_color_online: String

The color of an online online indicator.

theme_color_idle: String

The color of an idle online indicator.

theme_color_offline: String

The color of an offline online indicator.

disable_other_themes: boolenable_questions: boolmotivational_header: String

A header shown in the place of “Ask question” if enable_questions is true.

allow_anonymous_questions: bool

If questions from anonymous users are allowed. Requires enable_questions.

anonymous_username: String

The username used for anonymous users.

anonymous_avatar_url: String

The URL of the avatar used for anonymous users.

hide_dislikes: bool

If dislikes are hidden for the user.

require_account: bool

Require an account to view the user’s profile.

show_nsfw: bool

If NSFW content should be shown.

inbox_homepage: bool

Make your inbox your homepage.

muted: Vec<String>

A list of strings the user has muted.

enable_drawings: bool

If drawings are enabled for questions sent to the user.

all_timeline_hide_answers: bool

Hide posts that are answering a question on the “All” timeline.

large_text: bool

Increase the text size of buttons and paragraphs.

disable_achievements: bool

Disable achievements.

hide_from_social_lists: bool

If the user is hidden from followers/following tabs.

The user will still impact the followers/following numbers, but will not be shown in the UI (or API).

private_biography: String

Biography shown on profile/private.lisp page.

hide_social_follows: bool

If the followers/following links are hidden from the user’s profile. Will also revoke access to their respective pages.

location: String

The user’s location. This isn’t actually verified or anything, so it can really be whatever the user wants.

links: Vec<(String, String)>

External links for the user’s other profiles on other websites.

auto_nsfw: bool

Automatically mark new posts as NSFW.

auto_limit_posts: bool

Automatically limit the reach of new posts (don’t show them on public timelines).

Implementations