pub struct Post {Show 15 fields
pub id: Id,
pub created: u128,
pub content: String,
pub owner: Id,
pub context: PostContext,
pub replying_to: Option<Id>,
pub likes: isize,
pub dislikes: isize,
pub comment_count: usize,
pub uploads: Vec<usize>,
pub is_deleted: bool,
pub poll_id: Option<Id>,
pub views: usize,
pub group: Option<Id>,
pub limited_reach: bool,
}Fields
id: Idcreated: u128content: Stringowner: IdThe ID of the owner of this post.
context: PostContextExtra information about the post.
replying_to: Option<Id>The ID of the post this post is a comment on.
likes: isizedislikes: isizecomment_count: usizeuploads: Vec<usize>IDs of all uploads linked to this post.
is_deleted: boolIf the post was deleted.
poll_id: Option<Id>The ID of the poll associated with this post.
views: usizegroup: Option<Id>limited_reach: boolImplementations
Sourceimpl Post
impl Post
Sourcepub fn new(
content: String,
replying_to: Option<Id>,
owner: Id,
poll_id: Option<Id>,
group: Option<Id>,
) -> Self
pub fn new( content: String, replying_to: Option<Id>, owner: Id, poll_id: Option<Id>, group: Option<Id>, ) -> Self
Create a new Post.
Sourcepub fn repost(content: String, owner: Id, post_id: Id) -> Self
pub fn repost(content: String, owner: Id, post_id: Id) -> Self
Create a new Post (as a repost of the given post_id).
Sourcepub fn mark_as_repost(&mut self)
pub fn mark_as_repost(&mut self)
Make the given post a reposted post.
Sourcepub fn can_comment(&self) -> bool
pub fn can_comment(&self) -> bool
Check if a particular user can comment on this post.